==> ejc-tax-api-3.0.0-20210308.100003-93-sources.jar: com/ejianc/business/tax/vo/InvoiceOpenRecordVO.java <==
package com.ejianc.business.tax.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 有合同开票
 * </p>
 *
 * @author yqls
 * @since 2020-06-04
 */
public class InvoiceOpenRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    private Long contractId;
    /**
     * 发票金额（不含税）
     */
    private BigDecimal invoiceMny;

    /**
     * 税金
     */
    private BigDecimal taxMny;

    /**
     * 价税合计
     */
    private BigDecimal invoiceTaxMny;
    private BigDecimal contractTaxMny;

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    private List<InvoiceOpenVO> invoiceOpenVOList;

    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    public void setInvoiceTaxMny(BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }

    public List<InvoiceOpenVO> getInvoiceOpenVOList() {
        return invoiceOpenVOList;
    }

    public void setInvoiceOpenVOList(List<InvoiceOpenVO> invoiceOpenVOList) {
        this.invoiceOpenVOList = invoiceOpenVOList;
    }
}

==> ejc-tax-api-3.0.0-20220406.083417-262-sources.jar: com/ejianc/business/tax/vo/InvoiceOpenRecordVO.java <==
package com.ejianc.business.tax.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 合同开票
 * </p>
 *
 * @author yqls
 * @since 2020-06-04
 */
public class InvoiceOpenRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    private Long contractId;
    /**
     * 发票金额（不含税）
     */
    private BigDecimal invoiceMny;

    /**
     * 税金
     */
    private BigDecimal taxMny;

    /**
     * 价税合计
     */
    private BigDecimal invoiceTaxMny;
    private BigDecimal contractTaxMny;
    /**
     * 税率
     */
    private BigDecimal taxRate;

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    private List<InvoiceOpenVO> invoiceOpenVOList;

    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    public void setInvoiceTaxMny(BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }

    public List<InvoiceOpenVO> getInvoiceOpenVOList() {
        return invoiceOpenVOList;
    }

    public void setInvoiceOpenVOList(List<InvoiceOpenVO> invoiceOpenVOList) {
        this.invoiceOpenVOList = invoiceOpenVOList;
    }
}
